/***************************************************************************
                          guibutton.h  -  description
                             -------------------
    begin                : Tue Jun 15 2004
    copyright            : (C) 2004 by Harald Krippel
    email                : harald@hte-develop.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GUIOSBUTTON_H
#define GUIOSBUTTON_H

/**
  *@author Harald Krippel
  */

#include <plib/pu.h>

/*!

 This Class is the glue between PLIB puOneShot and QCake.

*/
class GUIOSButton : public puOneShot  {
public: 
	GUIOSButton(int minx, int miny, const char *l);
  void setText(const char *text);
	~GUIOSButton();
private:
  char legendtext[256];
};
#endif
